@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use Opt::Imistic ([ 'o' ]);
+use Opt::Imistic qw(1);
 use Data::Dumper;
 
 print Dumper (\%ARGV);
